==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/GridColumnGroupOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridColumnOptionsSimpleSectionBaseDescriptionMetadata } from "./GridColumnOptionsSimpleSectionBaseDescriptionMetadata";
import { GridColumnGroupOptionsDescription } from "./GridColumnGroupOptionsDescription";
/**
 * @hidden
 */
var GridColumnGroupOptionsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GridColumnGroupOptionsDescriptionMetadata, _super);
    function GridColumnGroupOptionsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridColumnGroupOptionsDescriptionMetadata.b = function (a) {
        if (GridColumnGroupOptionsDescriptionMetadata.a == null) {
            GridColumnGroupOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridColumnGroupOptionsDescriptionMetadata.c(GridColumnGroupOptionsDescriptionMetadata.a);
        }
        if (a.k(GridColumnGroupOptionsDescriptionMetadata.a)) {
            return;
        }
        a.ab(GridColumnGroupOptionsDescriptionMetadata.a);
    };
    GridColumnGroupOptionsDescriptionMetadata.c = function (a) {
        GridColumnOptionsSimpleSectionBaseDescriptionMetadata.c(a);
    };
    GridColumnGroupOptionsDescriptionMetadata.d = function (a) {
        GridColumnGroupOptionsDescriptionMetadata.b(a);
        a.ad("GridColumnGroupOptions", function () { return new GridColumnGroupOptionsDescription(); });
        a.ac("GridColumnGroupOptions", GridColumnGroupOptionsDescriptionMetadata.a);
    };
    GridColumnGroupOptionsDescriptionMetadata.$t = markType(GridColumnGroupOptionsDescriptionMetadata, 'GridColumnGroupOptionsDescriptionMetadata');
    GridColumnGroupOptionsDescriptionMetadata.a = null;
    return GridColumnGroupOptionsDescriptionMetadata;
}(Base));
export { GridColumnGroupOptionsDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/GridColumnGroupOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridColumnOptionsSimpleSectionBaseDescriptionMetadata } from "./GridColumnOptionsSimpleSectionBaseDescriptionMetadata";
import { GridColumnGroupOptionsDescription } from "./GridColumnGroupOptionsDescription";
/**
 * @hidden
 */
var GridColumnGroupOptionsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GridColumnGroupOptionsDescriptionMetadata, _super);
    function GridColumnGroupOptionsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridColumnGroupOptionsDescriptionMetadata.b = function (a) {
        if (GridColumnGroupOptionsDescriptionMetadata.a == null) {
            GridColumnGroupOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridColumnGroupOptionsDescriptionMetadata.c(GridColumnGroupOptionsDescriptionMetadata.a);
        }
        if (a.k(GridColumnGroupOptionsDescriptionMetadata.a)) {
            return;
        }
        a.ac(GridColumnGroupOptionsDescriptionMetadata.a);
    };
    GridColumnGroupOptionsDescriptionMetadata.c = function (a) {
        GridColumnOptionsSimpleSectionBaseDescriptionMetadata.c(a);
    };
    GridColumnGroupOptionsDescriptionMetadata.d = function (a) {
        GridColumnGroupOptionsDescriptionMetadata.b(a);
        a.ae("GridColumnGroupOptions", function () { return new GridColumnGroupOptionsDescription(); });
        a.ad("GridColumnGroupOptions", GridColumnGroupOptionsDescriptionMetadata.a);
    };
    GridColumnGroupOptionsDescriptionMetadata.$t = markType(GridColumnGroupOptionsDescriptionMetadata, 'GridColumnGroupOptionsDescriptionMetadata');
    GridColumnGroupOptionsDescriptionMetadata.a = null;
    return GridColumnGroupOptionsDescriptionMetadata;
}(Base));
export { GridColumnGroupOptionsDescriptionMetadata };
